@@ -54,8 +54,8 @@ pub enum ServerType {
 impl fmt::Display for ServerType {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match *self {
-            ServerType::Tcp => f.write_str("TCP"),
-            ServerType::Udp => f.write_str("UDP"),
+            Self::Tcp => f.write_str("TCP"),
+            Self::Udp => f.write_str("UDP"),
         }
     }
 }
@@ -71,8 +71,8 @@ pub struct PingBalancerBuilder {
 }
 
 impl PingBalancerBuilder {
-    pub fn new(context: Arc<ServiceContext>, mode: Mode) -> PingBalancerBuilder {
-        PingBalancerBuilder {
+    pub fn new(context: Arc<ServiceContext>, mode: Mode) -> Self {
+        Self {
             servers: Vec::new(),
             context,
             mode,
@@ -165,10 +165,7 @@ impl PingBalancerBuilder {
     pub async fn build(self) -> io::Result<PingBalancer> {
         if let Some(intv) = self.check_best_interval {
             if intv > self.check_interval {
-                return Err(io::Error::new(
-                    io::ErrorKind::Other,
-                    "check_interval must be >= check_best_interval",
-                ));
+                return Err(io::Error::other("check_interval must be >= check_best_interval"));
             }
         }
 
@@ -242,7 +239,7 @@ impl PingBalancerContext {
         max_server_rtt: Duration,
         check_interval: Duration,
         check_best_interval: Option<Duration>,
-    ) -> io::Result<(Arc<PingBalancerContext>, PingBalancerContextTask)> {
+    ) -> io::Result<(Arc<Self>, PingBalancerContextTask)> {
         let plugin_abortable = {
             // Start plugins for TCP proxies
 
@@ -274,7 +271,7 @@ impl PingBalancerContext {
                     check_fut.push(plugin.wait_started(Duration::from_secs(3)));
                 }
 
-                // Run all of them simutaneously
+                // Run all of them simultaneously
                 let _ = future::join_all(check_fut).await;
 
                 let plugin_abortable = tokio::spawn(async move {
@@ -306,7 +303,7 @@ impl PingBalancerContext {
 
         let (best_tcp_idx, best_udp_idx) = PingBalancerBuilder::find_best_idx(&servers, mode);
 
-        let balancer_context = PingBalancerContext {
+        let balancer_context = Self {
             servers,
             best_tcp_idx: AtomicUsize::new(best_tcp_idx),
             best_udp_idx: AtomicUsize::new(best_udp_idx),
@@ -361,10 +358,10 @@ impl PingBalancerContext {
 
         for server in self.servers.iter() {
             let svr_cfg = server.server_config();
-            if self.mode.enable_tcp() && PingBalancerContext::check_server_tcp_enabled(svr_cfg) {
+            if self.mode.enable_tcp() && Self::check_server_tcp_enabled(svr_cfg) {
                 tcp_count += 1;
             }
-            if self.mode.enable_udp() && PingBalancerContext::check_server_udp_enabled(svr_cfg) {
+            if self.mode.enable_udp() && Self::check_server_udp_enabled(svr_cfg) {
                 udp_count += 1;
             }
         }
@@ -398,7 +395,7 @@ impl PingBalancerContext {
         for server in servers.iter() {
             let svr_cfg = server.server_config();
 
-            if self.mode.enable_tcp() && PingBalancerContext::check_server_tcp_enabled(svr_cfg) {
+            if self.mode.enable_tcp() && Self::check_server_tcp_enabled(svr_cfg) {
                 let checker = PingChecker {
                     server: server.clone(),
                     server_type: ServerType::Tcp,
@@ -408,7 +405,7 @@ impl PingBalancerContext {
                 vfut_tcp.push(checker.check_update_score());
             }
 
-            if self.mode.enable_udp() && PingBalancerContext::check_server_udp_enabled(svr_cfg) {
+            if self.mode.enable_udp() && Self::check_server_udp_enabled(svr_cfg) {
                 let checker = PingChecker {
                     server: server.clone(),
                     server_type: ServerType::Udp,
@@ -524,7 +521,7 @@ impl PingBalancerContext {
         let mut check_tcp = false;
         let mut check_udp = false;
 
-        if self.mode.enable_tcp() && PingBalancerContext::check_server_tcp_enabled(best_tcp_svr_cfg) {
+        if self.mode.enable_tcp() && Self::check_server_tcp_enabled(best_tcp_svr_cfg) {
             let checker = PingChecker {
                 server: best_tcp_server.clone(),
                 server_type: ServerType::Tcp,
@@ -535,7 +532,7 @@ impl PingBalancerContext {
             check_tcp = true;
         }
 
-        if self.mode.enable_udp() && PingBalancerContext::check_server_udp_enabled(best_udp_svr_cfg) {
+        if self.mode.enable_udp() && Self::check_server_udp_enabled(best_udp_svr_cfg) {
             let checker = PingChecker {
                 server: best_udp_server.clone(),
                 server_type: ServerType::Udp,
@@ -1033,7 +1030,7 @@ struct ServerConfigFormatter<'a> {
 }
 
 impl<'a> ServerConfigFormatter<'a> {
-    fn new(server_config: &'a ServerConfig) -> ServerConfigFormatter<'a> {
+    fn new(server_config: &'a ServerConfig) -> Self {
         ServerConfigFormatter { server_config }
     }
 }
