@@ -10,10 +10,9 @@ use std::{
 use log::{debug, error, info, trace, warn};
 use lru_time_cache::LruCache;
 use shadowsocks::{
-    lookup_then,
-    net::{get_ip_stack_capabilities, ConnectOpts},
+    ServerAddr, lookup_then,
+    net::{ConnectOpts, get_ip_stack_capabilities},
     relay::{socks5::Address, udprelay::MAXIMUM_UDP_PAYLOAD_SIZE},
-    ServerAddr,
 };
 use tokio::{sync::Mutex, task::JoinHandle, time};
 
@@ -47,7 +46,7 @@ impl Drop for UdpRedirInboundCache {
 }
 
 impl UdpRedirInboundCache {
-    fn new() -> UdpRedirInboundCache {
+    fn new() -> Self {
         let cache = Arc::new(Mutex::new(LruCache::with_expiry_duration_and_capacity(
             INBOUND_SOCKET_CACHE_EXPIRATION,
             INBOUND_SOCKET_CACHE_CAPACITY,
@@ -63,7 +62,7 @@ impl UdpRedirInboundCache {
             })
         };
 
-        UdpRedirInboundCache { cache, watcher }
+        Self { cache, watcher }
     }
 }
 
@@ -76,8 +75,8 @@ struct UdpRedirInboundWriter {
 
 impl UdpRedirInboundWriter {
     #[allow(unused_variables, clippy::needless_update)]
-    fn new(redir_ty: RedirType, opts: &ConnectOpts) -> UdpRedirInboundWriter {
-        UdpRedirInboundWriter {
+    fn new(redir_ty: RedirType, opts: &ConnectOpts) -> Self {
+        Self {
             redir_ty,
             socket_opts: RedirSocketOpts {
                 #[cfg(any(target_os = "linux", target_os = "android"))]
@@ -133,21 +132,22 @@ impl UdpInboundWrite for UdpRedirInboundWriter {
 
         let inbound = {
             let mut cache = self.inbound_cache.cache.lock().await;
-            if let Some(socket) = cache.get(&addr) {
-                socket.clone()
-            } else {
-                // Create a socket binds to destination addr
-                // This only works for systems that supports binding to non-local addresses
-                //
-                // This socket has to set SO_REUSEADDR and SO_REUSEPORT.
-                // Outbound addresses could be connected from different source addresses.
-                let inbound = UdpRedirSocket::bind_nonlocal(self.redir_ty, addr, &self.socket_opts)?;
+            match cache.get(&addr) {
+                Some(socket) => socket.clone(),
+                _ => {
+                    // Create a socket binds to destination addr
+                    // This only works for systems that supports binding to non-local addresses
+                    //
+                    // This socket has to set SO_REUSEADDR and SO_REUSEPORT.
+                    // Outbound addresses could be connected from different source addresses.
+                    let inbound = UdpRedirSocket::bind_nonlocal(self.redir_ty, addr, &self.socket_opts)?;
 
-                // UDP socket could be shared between threads and is safe to be manipulated by multiple threads
-                let inbound = Arc::new(inbound);
-                cache.insert(addr, inbound.clone());
+                    // UDP socket could be shared between threads and is safe to be manipulated by multiple threads
+                    let inbound = Arc::new(inbound);
+                    cache.insert(addr, inbound.clone());
 
-                inbound
+                    inbound
+                }
             }
         };
 
@@ -185,10 +185,7 @@ impl UdpInboundWrite for UdpRedirInboundWriter {
 
                 trace!(
                     "udp redir send back data {} bytes, remote: {}, peer: {}, socket_opts: {:?}",
-                    n,
-                    remote_addr,
-                    peer_addr,
-                    self.socket_opts
+                    n, remote_addr, peer_addr, self.socket_opts
                 );
 
                 Ok(())
@@ -215,7 +212,7 @@ impl RedirUdpServer {
         time_to_live: Option<Duration>,
         capacity: Option<usize>,
         balancer: PingBalancer,
-    ) -> io::Result<RedirUdpServer> {
+    ) -> io::Result<Self> {
         let listener = match *client_config {
             ServerAddr::SocketAddr(ref saddr) => UdpRedirSocket::listen(redir_ty, *saddr)?,
             ServerAddr::DomainName(ref dname, port) => {
@@ -226,7 +223,7 @@ impl RedirUdpServer {
             }
         };
 
-        Ok(RedirUdpServer {
+        Ok(Self {
             context,
             redir_ty,
             time_to_live,
